@@ -29,9 +29,15 @@ Utilities for working with dates and times.
 #  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 #  MA 02110-1301, USA.
 #
+#  calc_easter from https://code.activestate.com/recipes/576517-calculate-easter-western-given-a-year/
+#  Copyright © 2008 Martin Diers
+#  Licensed under the MIT License
+#
 
 # stdlib
 import datetime
+import sys
+import typing
 from collections import OrderedDict
 from typing import Optional, Union
 
@@ -43,6 +49,7 @@ __all__ = [
 		"parse_month",
 		"get_month_number",
 		"check_date",
+		"calc_easter",
 		]
 
 try:
@@ -56,12 +63,10 @@ try:
 			) -> Optional[datetime.timedelta]:
 		"""
 		Returns the offset between UTC and the requested timezone on the given date.
-		If ``date`` is ``None`` then the current date is used.
+		If ``date`` is :py:obj:`None` then the current date is used.
 
 		:param tz: ``pytz.timezone`` or a string representing the timezone
 		:param date: The date to obtain the UTC offset for
-
-		:return:
 		"""
 
 		if date is None:
@@ -79,12 +84,10 @@ try:
 	def get_timezone(tz: str, date: Optional[datetime.datetime] = None) -> Optional[datetime.tzinfo]:
 		"""
 		Returns a localized :class:`pytz.timezone` object for the given date.
-		If ``date`` is ``None`` then the current date is used.
+		If ``date`` is :py:obj:`None` then the current date is used.
 
 		:param tz: A string representing a pytz timezone
 		:param date: The date to obtain the timezone for
-
-		:return:
 		"""
 
 		if date is None:
@@ -113,9 +116,7 @@ The error was {e}.
 
 def current_tzinfo() -> Optional[datetime.tzinfo]:
 	"""
-	Returns a tzinfo object for the current timezone
-
-	:rtype: :class:`python:datetime.tzinfo`
+	Returns a tzinfo object for the current timezone.
 	"""
 
 	return datetime.datetime.now().astimezone().tzinfo  # pragma: no cover (hard to test)
@@ -130,7 +131,7 @@ def current_tzinfo() -> Optional[datetime.tzinfo]:
 # 	:type datetime: :class:`datetime.datetime`
 # 	:param current_tzinfo: A tzinfo object representing the current timezone.
 # 		If None it will be inferred.
-# 	:type current_tzinfo: :class:`~python:datetime.tzinfo`
+# 	:type current_tzinfo: :class:`datetime.tzinfo`
 #
 # 	:return: Timestamp in UTC timezone
 # 	:rtype: float
@@ -144,12 +145,10 @@ def set_timezone(obj: datetime.datetime, tzinfo: datetime.tzinfo) -> datetime.da
 	"""
 	Sets the timezone / tzinfo of the given :class:`datetime.datetime` object.
 	This will not convert the time (i.e. the hours will stay the same).
-	Use :meth:`python:datetime.datetime.astimezone` to accomplish that.
+	Use :meth:`datetime.datetime.astimezone` to accomplish that.
 
 	:param obj:
 	:param tzinfo:
-
-	:return:
 	"""
 
 	return obj.replace(tzinfo=tzinfo)
@@ -165,7 +164,7 @@ def utc_timestamp_to_datetime(
 	If ``output_tz`` is None the timestamp is converted to the platform’s local date and time,
 	and the local timezone is inferred and set for the object.
 
-	If ``output_tz`` is not None, it must be an instance of a :class:`~python:datetime.tzinfo` subclass,
+	If ``output_tz`` is not None, it must be an instance of a :class:`datetime.tzinfo` subclass,
 	and the timestamp is converted to ``output_tz``’s time zone.
 
 
@@ -175,7 +174,7 @@ def utc_timestamp_to_datetime(
 
 	:return: The timestamp as a datetime object.
 
-	:raises: :class:`~python:OverflowError` if the timestamp is out of the range
+	:raises OverflowError: if the timestamp is out of the range
 		of values supported by the platform C localtime() or gmtime() functions,
 		and OSError on localtime() or gmtime() failure. It’s common for this to
 		be restricted to years in 1970 through 2038.
@@ -185,8 +184,13 @@ def utc_timestamp_to_datetime(
 	return new_datetime.astimezone(output_tz)
 
 
-# Mapping of months to their 3-character shortcodes.
-months = OrderedDict(
+if sys.version_info <= (3, 7, 2):
+	MonthsType = OrderedDict
+else:
+	MonthsType = typing.OrderedDict[str, str]  # type: ignore  # noqa: TYP006
+
+#: Mapping of 3-character shortcodes to full month names.
+months: MonthsType = OrderedDict(
 		Jan="January",
 		Feb="February",
 		Mar="March",
@@ -269,3 +273,24 @@ def check_date(month: Union[str, int], day: int, leap_year: bool = True) -> bool
 		return True
 	except ValueError:
 		return False
+
+
+def calc_easter(year: int) -> datetime.date:
+	"""
+	Returns the date of Easter in the given year.
+
+	:param year:
+
+	.. versionadded:: 1.4.0
+	"""
+
+	a = year % 19
+	b = year // 100
+	c = year % 100
+	d = (19 * a + b - b // 4 - ((b - (b + 8) // 25 + 1) // 3) + 15) % 30
+	e = (32 + 2 * (b % 4) + 2 * (c // 4) - d - (c % 4)) % 7
+	f = d + e - 7 * ((a + 11 * d + 22 * e) // 451) + 114
+	month = f // 31
+	day = f % 31 + 1
+
+	return datetime.date(year, month, day)
