@@ -4,9 +4,9 @@
 """
 Functions for paths and files.
 
-.. versionchanged:: 0.8.0
+.. versionchanged:: 1.0.0
 
-	``relpath2`` is deprecated and will be removed in 1.0.0.
+	Removed ``relpath2``.
 	Use :func:`domdf_python_tools.paths.relpath` instead.
 """
 #
@@ -40,15 +40,16 @@ Functions for paths and files.
 #
 
 # stdlib
+import contextlib
 import json
 import os
 import pathlib
 import shutil
 import stat
-from typing import IO, Any, Callable, Iterable, List, Optional
+import sys
+from typing import IO, Any, Callable, Iterable, List, Optional, TypeVar, Union
 
 # this package
-from domdf_python_tools.stringlist import StringList
 from domdf_python_tools.typing import JsonLibrary, PathLike
 
 __all__ = [
@@ -65,9 +66,15 @@ __all__ = [
 		"PathPlus",
 		"PosixPathPlus",
 		"WindowsPathPlus",
+		"in_directory",
+		"_P",
 		]
 
 newline_default = object()
+_P = TypeVar("_P", bound=pathlib.PurePath)
+"""
+.. versionadded:: 0.11.0
+"""
 
 
 def append(var: str, filename: PathLike, **kwargs) -> int:
@@ -107,15 +114,14 @@ def copytree(
 		added in the list of errors raised in an Error exception at the end of
 		the copy process. You can set the optional ignore_dangling_symlinks
 		flag to true if you want to silence this exception. Notice that this
-		option has no effect on platforms that don’t support :class:`python:os.symlink`.
-	:type symlinks: bool, optional
+		option has no effect on platforms that don’t support :func:`os.symlink`.
 	:param ignore: A callable that will receive as its arguments the source
 		directory, and a list of its contents. The ignore callable will be
 		called once for each directory that is copied. The callable must return
 		a sequence of directory and file names relative to the current
 		directory (i.e. a subset of the items in its second argument); these
 		names will then be ignored in the copy process.
-		:class:`python:shutil.ignore_patterns` can be used to create such a callable
+		:func:`shutil.ignore_patterns` can be used to create such a callable
 		that ignores names based on
 		glob-style patterns.
 	"""
@@ -147,25 +153,22 @@ def maybe_make(directory: PathLike, mode: int = 0o777, parents: bool = False, ex
 	"""
 	Create a directory at the given path, but only if the directory does not already exist.
 
-	.. note::
+	.. attention::
 
 		This will fail silently if a file with the same name already exists.
 		This appears to be due to the behaviour of :func:`os.mkdir`.
 
 	:param directory: Directory to create
 	:param mode: Combined with the process’ umask value to determine the file mode and access flags
-	:type mode:
-	:param parents: If :py:obj:`False` (the default), a missing parent raises a :class:`~python:FileNotFoundError`.
+	:param parents: If :py:obj:`False` (the default), a missing parent raises a :class:`FileNotFoundError`.
 		If :py:obj:`True`, any missing parents of this path are created as needed; they are created with the
 		default permissions without taking mode into account (mimicking the POSIX mkdir -p command).
 	:no-default parents:
-	:type parents: bool, optional
-	:param exist_ok: If :py:obj:`False` (the default), a :class:`~python:FileExistsError` is raised if the
-		target directory already exists. If :py:obj:`True`, :class:`~python:FileExistsError` exceptions
+	:param exist_ok: If :py:obj:`False` (the default), a :class:`FileExistsError` is raised if the
+		target directory already exists. If :py:obj:`True`, :class:`FileExistsError` exceptions
 		will be ignored (same behavior as the POSIX mkdir -p command), but only if the last path
 		component is not an existing non-directory file.
 	:no-default exist_ok:
-	:type exist_ok: bool, optional
 	"""
 
 	if not isinstance(directory, pathlib.Path):
@@ -196,9 +199,9 @@ def read(filename: PathLike, **kwargs) -> str:
 
 	.. TODO:: make this the file in the given directory, by default the current directory
 
-	:param filename: The file to read from
+	:param filename: The file to read from.
 
-	:return: The contents of the file
+	:return: The contents of the file.
 	"""
 
 	with open(os.path.join(os.getcwd(), filename), **kwargs) as f:
@@ -214,9 +217,7 @@ def relpath(path: PathLike, relative_to: Optional[PathLike] = None) -> pathlib.P
 	:param relative_to: The directory to find the path relative to.
 		Defaults to the current directory.
 	:no-default relative_to:
-
-	:return:
-	"""
+	"""  # noqa D400
 
 	if not isinstance(path, pathlib.Path):
 		path = pathlib.Path(path)
@@ -237,17 +238,14 @@ def relpath(path: PathLike, relative_to: Optional[PathLike] = None) -> pathlib.P
 		return abs_path
 
 
-relpath2 = relpath
-
-
 def write(var: str, filename: PathLike, **kwargs) -> None:
 	"""
 	Write a variable to file in the current directory.
 
 	.. TODO:: make this the file in the given directory, by default the current directory
 
-	:param var: The value to write to the file
-	:param filename: The file to write to
+	:param var: The value to write to the file.
+	:param filename: The file to write to.
 	"""
 
 	with open(os.path.join(os.getcwd(), filename), 'w', **kwargs) as f:
@@ -262,6 +260,9 @@ def clean_writer(string: str, fp: IO) -> None:
 	:param fp:
 	"""
 
+	# this package
+	from domdf_python_tools.stringlist import StringList
+
 	buffer = StringList(string)
 	buffer.blankline(ensure_single=True)
 	fp.write(str(buffer))
@@ -281,9 +282,26 @@ def make_executable(filename: PathLike) -> None:
 	os.chmod(str(filename), st.st_mode | stat.S_IXUSR | stat.S_IXGRP | stat.S_IXOTH)
 
 
+@contextlib.contextmanager
+def in_directory(directory: PathLike):
+	"""
+	Context manager to change into the given directory for the
+	duration of the ``with`` block.
+
+	:param directory:
+	"""  # noqa: D400
+
+	oldwd = os.getcwd()
+	try:
+		os.chdir(str(directory))
+		yield
+	finally:
+		os.chdir(oldwd)
+
+
 class PathPlus(pathlib.Path):
 	"""
-	Subclass of :mod:`pathlib.Path` with additional methods and a default encoding of UTF-8.
+	Subclass of :class:`pathlib.Path` with additional methods and a default encoding of UTF-8.
 
 	Path represents a filesystem path but unlike PurePath, also offers
 	methods to do system calls on path objects. Depending on your system,
@@ -298,9 +316,11 @@ class PathPlus(pathlib.Path):
 		Defaults to Unix line endings (``LF``) on all platforms.
 	"""
 
-	def __new__(cls, *args, **kwargs):
+	__slots__ = ("_accessor", )
+
+	def __new__(cls, *args, **kwargs):  # noqa D102
 		if cls is PathPlus:
-			cls = WindowsPathPlus if os.name == 'nt' else PosixPathPlus
+			cls = WindowsPathPlus if os.name == "nt" else PosixPathPlus
 
 		self = cls._from_parts(args, init=False)  # type: ignore
 		if not self._flavour.is_supported:
@@ -309,10 +329,12 @@ class PathPlus(pathlib.Path):
 		self._init()
 		return self
 
-	def make_executable(self):
+	def make_executable(self) -> None:
 		"""
 		Make the file executable.
 
+		:rtype:
+
 		.. versionadded:: 0.3.8
 		"""
 
@@ -325,12 +347,14 @@ class PathPlus(pathlib.Path):
 			errors: Optional[str] = None,
 			):
 		"""
-		Open the file in text mode, write to it without trailing spaces, and close the file.
+		Write to the file without trailing whitespace, and with a newline at the end of the file.
 
 		:param string:
-		:param encoding: The encoding to write to the file using.
+		:param encoding: The encoding to write to the file in.
 		:param errors:
 
+		:rtype:
+
 		.. versionadded:: 0.3.8
 		"""
 
@@ -352,18 +376,17 @@ class PathPlus(pathlib.Path):
 			This appears to be due to the behaviour of :func:`os.mkdir`.
 
 		:param mode: Combined with the process’ umask value to determine the file mode and access flags
-		:type mode:
-		:param parents: If :py:obj:`False` (the default), a missing parent raises a :class:`~python:FileNotFoundError`.
+		:param parents: If :py:obj:`False` (the default), a missing parent raises a :class:`FileNotFoundError`.
 			If :py:obj:`True`, any missing parents of this path are created as needed; they are created with the
 			default permissions without taking mode into account (mimicking the POSIX mkdir -p command).
 		:no-default parents:
-		:type parents: bool, optional
-		:param exist_ok: If :py:obj:`False` (the default), a :class:`~python:FileExistsError` is raised if the
-			target directory already exists. If :py:obj:`True`, :class:`~python:FileExistsError` exceptions
+		:param exist_ok: If :py:obj:`False` (the default), a :class:`FileExistsError` is raised if the
+			target directory already exists. If :py:obj:`True`, :class:`FileExistsError` exceptions
 			will be ignored (same behavior as the POSIX mkdir -p command), but only if the last path
 			component is not an existing non-directory file.
 		:no-default exist_ok:
-		:type exist_ok: bool, optional
+
+		:rtype:
 
 		.. versionadded:: 0.3.8
 		"""
@@ -380,10 +403,11 @@ class PathPlus(pathlib.Path):
 		Open the file in text mode, append the given string to it, and close the file.
 
 		:param string:
-		:type string: str
-		:param encoding: The encoding to write to the file using.
+		:param encoding: The encoding to write to the file in.
 		:param errors:
 
+		:rtype:
+
 		.. versionadded:: 0.3.8
 		"""
 
@@ -400,10 +424,11 @@ class PathPlus(pathlib.Path):
 		Open the file in text mode, write to it, and close the file.
 
 		:param data:
-		:type data: str
-		:param encoding: The encoding to write to the file using.
+		:param encoding: The encoding to write to the file in.
 		:param errors:
 
+		:rtype:
+
 		.. versionadded:: 0.3.8
 		"""
 
@@ -416,16 +441,14 @@ class PathPlus(pathlib.Path):
 			errors: Optional[str] = None,
 			) -> None:
 		"""
-		Open the file in text mode, write the given list of lines to it without trailing spaces,
-		and close the file.
+		Write the given list of lines to the file without trailing whitespace.
 
 		:param data:
-		:type data: str
-		:param encoding: The encoding to write to the file using.
+		:param encoding: The encoding to write to the file in.
 		:param errors:
 
 		.. versionadded:: 0.5.0
-		"""
+		"""  # noqa D400
 
 		return self.write_clean("\n".join(data), encoding=encoding, errors=errors)
 
@@ -437,7 +460,7 @@ class PathPlus(pathlib.Path):
 		"""
 		Open the file in text mode, read it, and close the file.
 
-		:param encoding: The encoding to write to the file using.
+		:param encoding: The encoding to write to the file in.
 		:param errors:
 
 		:return: The content of the file.
@@ -456,47 +479,42 @@ class PathPlus(pathlib.Path):
 		Open the file in text mode, return a list containing the lines in the file,
 		and close the file.
 
-		:param encoding: The encoding to write to the file using.
+		:param encoding: The encoding to write to the file in.
 		:param errors:
 
 		:return: The content of the file.
 
 		.. versionadded:: 0.5.0
-		"""
+		"""  # noqa D400
 
 		return self.read_text(encoding=encoding, errors=errors).split("\n")
 
-	def open(
-			self,
-			mode: str = "r",
-			buffering: int = -1,
-			encoding: Optional[str] = "UTF-8",
-			errors: Optional[str] = None,
-			newline: Optional[str] = newline_default,  # type: ignore
-			) -> IO[Any]:
+	def open(  # type: ignore  # noqa A003
+		self,
+		mode: str = "r",
+		buffering: int = -1,
+		encoding: Optional[str] = "UTF-8",
+		errors: Optional[str] = None,
+		newline: Optional[str] = newline_default,  # type: ignore
+		) -> IO[Any]:
 		"""
 		Open the file pointed by this path and return a file object, as
-		the built-in open() function does.
+		the built-in :func:`open` function does.
 
 		:param mode: The mode to open the file in.
 		:default mode: ``'r'`` (read only)
-		:type mode: str
 		:param buffering:
-		:type buffering: int
 		:param encoding:
-		:type encoding: str
 		:param errors:
 		:param newline:
 		:default newline: `universal newlines <https://docs.python.org/3/glossary.html#term-universal-newlines>`__ for reading, Unix line endings (``LF``) for writing.
 
-		:return:
-
 		.. versionadded:: 0.3.8
 
 		.. versionchanged:: 0.5.1
 
 			Defaults to Unix line endings (``LF``) on all platforms.
-		"""
+		"""  # noqa D400
 
 		if 'b' in mode:
 			encoding = None
@@ -508,7 +526,13 @@ class PathPlus(pathlib.Path):
 			else:
 				newline = "\n"
 
-		return super().open(mode, buffering=buffering, encoding=encoding, errors=errors, newline=newline)
+		return super().open(
+				mode,
+				buffering=buffering,
+				encoding=encoding,
+				errors=errors,
+				newline=newline,
+				)
 
 	def dump_json(
 			self,
@@ -517,21 +541,27 @@ class PathPlus(pathlib.Path):
 			errors: Optional[str] = None,
 			json_library: JsonLibrary = json,  # type: ignore
 			**kwargs,
-			) -> int:
+			) -> None:
 		"""
 		Dump ``data`` to the file as JSON.
 
 		:param data: The object to serialise to JSON.
-		:param encoding: The encoding to write to the file using.
+		:param encoding: The encoding to write to the file in.
 		:param errors:
 		:param json_library: The JSON serialisation library to use.
 		:default json_library: :mod:`json`
 		:param kwargs: Keyword arguments to pass to the JSON serialisation function.
 
 		.. versionadded:: 0.5.0
+
+		.. versionchanged:: 1.0.0
+
+			Now uses :meth:`PathPlus.write_clean <domdf_python_tools.paths.PathPlus.write_clean>`
+			rather than :meth:`PathPlus.write_text <domdf_python_tools.paths.PathPlus.write_text>`,
+			and returns :py:obj:`None` rather than :class:`int`.
 		"""
 
-		return self.write_text(
+		return self.write_clean(
 				json_library.dumps(data, **kwargs),
 				encoding=encoding,
 				errors=errors,
@@ -547,7 +577,7 @@ class PathPlus(pathlib.Path):
 		"""
 		Load JSON data from the file.
 
-		:param encoding: The encoding to write to the file using.
+		:param encoding: The encoding to write to the file in.
 		:param errors:
 		:param json_library: The JSON serialisation library to use.
 		:default json_library: :mod:`json`
@@ -563,33 +593,179 @@ class PathPlus(pathlib.Path):
 				**kwargs,
 				)
 
+	if sys.version_info < (3, 7):
+
+		def is_mount(self) -> bool:
+			"""
+			Check if this path is a POSIX mount point.
+
+			:rtype:
+
+			.. versionadded:: 0.3.8 for Python 3.7 and above
+			.. versionadded:: 0.11.0 for Python 3.6
+			"""
+
+			# Need to exist and be a dir
+			if not self.exists() or not self.is_dir():
+				return False
+
+			parent = pathlib.Path(self.parent)
+			try:
+				parent_dev = parent.stat().st_dev
+			except OSError:
+				return False
+
+			dev = self.stat().st_dev
+			if dev != parent_dev:
+				return True
+			ino = self.stat().st_ino
+			parent_ino = parent.stat().st_ino
+			return ino == parent_ino
+
+	if sys.version_info < (3, 8):
+
+		def rename(self: _P, target: Union[str, pathlib.PurePath]) -> _P:  # type: ignore
+			"""
+			Rename this path to the target path.
+
+			The target path may be absolute or relative. Relative paths are
+			interpreted relative to the current working directory, *not* the
+			directory of the Path object.
+
+			:param target:
+
+			:returns: The new Path instance pointing to the target path.
+
+			.. versionadded:: 0.3.8 for Python 3.8 and above
+			.. versionadded:: 0.11.0 for Python 3.6 and Python 3.7
+			"""
+
+			self._accessor.rename(self, target)  # type: ignore
+			return self.__class__(target)
+
+		def replace(self: _P, target: Union[str, pathlib.PurePath]) -> _P:  # type: ignore
+			"""
+			Rename this path to the target path, overwriting if that path exists.
+
+			The target path may be absolute or relative. Relative paths are
+			interpreted relative to the current working directory, *not* the
+			directory of the Path object.
+
+			Returns the new Path instance pointing to the target path.
+
+			:param target:
+
+			:returns: The new Path instance pointing to the target path.
+
+			.. versionadded:: 0.3.8 for Python 3.8 and above
+			.. versionadded:: 0.11.0 for Python 3.6 and Python 3.7
+			"""
+
+			self._accessor.replace(self, target)  # type: ignore
+			return self.__class__(target)
+
+		def unlink(self, missing_ok: bool = False) -> None:
+			"""
+			Remove this file or link.
+
+			If the path is a directory, use :meth:`~domdf_python_tools.paths.PathPlus.rmdir()` instead.
+
+			.. versionadded:: 0.3.8 for Python 3.8 and above
+			.. versionadded:: 0.11.0 for Python 3.6 and Python 3.7
+			"""
+
+			try:
+				self._accessor.unlink(self)  # type: ignore
+			except FileNotFoundError:
+				if not missing_ok:
+					raise
+
+	if sys.version_info < (3, 9):
+
+		def __enter__(self):
+			return self
+
+		def __exit__(self, t, v, tb):
+			# https://bugs.python.org/issue39682
+			# In previous versions of pathlib, this method marked this path as
+			# closed; subsequent attempts to perform I/O would raise an IOError.
+			# This functionality was never documented, and had the effect of
+			# making Path objects mutable, contrary to PEP 428. In Python 3.9 the
+			# _closed attribute was removed, and this method made a no-op.
+			# This method and __enter__()/__exit__() should be deprecated and
+			# removed in the future.
+			pass
+
+		def is_relative_to(self, *other: Union[str, os.PathLike]) -> bool:
+			r"""
+			Returns whether the path is relative to another path.
+
+			:param \*other:
+
+			:rtype:
+
+			.. versionadded:: 0.3.8 for Python 3.9 and above
+			.. versionadded:: 1.4.0 for Python 3.6 and Python 3.7
+			"""
+
+			try:
+				self.relative_to(*other)
+				return True
+			except ValueError:
+				return False
+
+	def abspath(self) -> "PathPlus":
+		"""
+		Return the absolute version of the path.
+
+		:rtype:
+
+		.. versionadded:: 1.3.0
+		"""
+
+		return self.__class__(os.path.abspath(self))
+
 
 class PosixPathPlus(PathPlus, pathlib.PurePosixPath):
 	"""
-	PathPlus subclass for non-Windows systems.
+	:class:`~.PathPlus` subclass for non-Windows systems.
 
 	On a POSIX system, instantiating a PathPlus object should return an instance of this class.
 
 	.. versionadded:: 0.3.8
 	"""
+
 	__slots__ = ()
 
 
 class WindowsPathPlus(PathPlus, pathlib.PureWindowsPath):
 	"""
-	PathPlus subclass for Windows systems.
+	:class:`~.PathPlus` subclass for Windows systems.
 
 	On a Windows system, instantiating a PathPlus object should return an instance of this class.
 
 	.. versionadded:: 0.3.8
 	"""
+
 	__slots__ = ()
 
 	def owner(self):  # pragma: no cover
+		"""
+		Unsupported on Windows.
+		"""
+
 		raise NotImplementedError("Path.owner() is unsupported on this system")
 
 	def group(self):  # pragma: no cover
+		"""
+		Unsupported on Windows.
+		"""
+
 		raise NotImplementedError("Path.group() is unsupported on this system")
 
 	def is_mount(self):  # pragma: no cover
+		"""
+		Unsupported on Windows.
+		"""
+
 		raise NotImplementedError("Path.is_mount() is unsupported on this system")
