@@ -65,6 +65,9 @@ __all__ = [
 		"alpha_sort",
 		"as_text",
 		"word_join",
+		"TAB",
+		"CR",
+		"LF",
 		]
 
 ascii_digits = "0123456789"
@@ -209,7 +212,7 @@ class Font(Dict[str, str]):
 		:return:
 		"""
 
-		return "".join(self[char] for char in text)
+		return ''.join(self[char] for char in text)
 
 	def get(self, char: str, default: Optional[str] = None) -> str:  # type: ignore
 		"""
@@ -313,7 +316,7 @@ SERIF_ITALIC_LETTERS = make_font(
 """
 Italic Serif :class:`domdf_python_tools.words.Font`
 
-This font includes and Greek letters.
+This font includes Greek letters.
 
 .. versionadded:: 0.7.0
 """
@@ -422,7 +425,7 @@ This font includes Greek letters.
 #: Script letters (uppercase)
 SCRIPT_UPPER = "𝓐𝓑𝓒𝓓𝓔𝓕𝓖𝓗𝓘𝓙𝓚𝓛𝓜𝓝𝓞𝓟𝓠𝓡𝓢𝓣𝓤𝓥𝓦𝓧𝓨𝓩"
 #: Script letters (lowercase)
-SCRIPT_LOWER = '𝓪𝓫𝓬𝓭𝓮𝓯𝓰𝓱𝓲𝓳𝓴𝓵𝓶𝓷𝓸𝓹𝓺𝓻𝓼𝓽𝓾𝓿𝔀𝔁𝔂𝔃'
+SCRIPT_LOWER = "𝓪𝓫𝓬𝓭𝓮𝓯𝓰𝓱𝓲𝓳𝓴𝓵𝓶𝓷𝓸𝓹𝓺𝓻𝓼𝓽𝓾𝓿𝔀𝔁𝔂𝔃"
 
 SCRIPT_LETTERS = make_font(SCRIPT_UPPER, SCRIPT_LOWER)
 """
@@ -537,3 +540,25 @@ def word_join(
 			return delimiter.join(words[:-1]) + f"{delimiter}{connective} {words[-1]}"
 		else:
 			return delimiter.join(words[:-1]) + f" {connective} {words[-1]}"
+
+
+TAB = "\t"
+"""
+A literal ``TAB`` (``\\t``) character for use in f-strings.
+
+.. versionadded:: 1.3.0
+"""
+
+CR = "\r"
+"""
+The carriage return character (``\\r``) for use in f-strings.
+
+.. versionadded:: 1.3.0
+"""
+
+LF = "\r"
+"""
+The newline character (``\\n``) for use in f-strings.
+
+.. versionadded:: 1.3.0
+"""
